==> zio-aws-mgn_2.13-5.17.155.1-sources.jar: zio/aws/mgn/model/DescribeVcenterClientsResponse.scala <==
package zio.aws.mgn.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mgn.model.primitives.PaginationToken
import scala.jdk.CollectionConverters._
final case class DescribeVcenterClientsResponse(
    items: Option[Iterable[zio.aws.mgn.model.VcenterClient]] = None,
    nextToken: Option[PaginationToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse = {
    import DescribeVcenterClientsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.DescribeVcenterClientsResponse.ReadOnly =
    zio.aws.mgn.model.DescribeVcenterClientsResponse.wrap(buildAwsValue())
}
object DescribeVcenterClientsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.DescribeVcenterClientsResponse =
      zio.aws.mgn.model.DescribeVcenterClientsResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Option[List[zio.aws.mgn.model.VcenterClient.ReadOnly]]
    def nextToken: Option[PaginationToken]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.mgn.model.VcenterClient.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse
  ) extends zio.aws.mgn.model.DescribeVcenterClientsResponse.ReadOnly {
    override val items: Option[List[zio.aws.mgn.model.VcenterClient.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.mgn.model.VcenterClient.wrap(item)
          }.toList
        )
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.mgn.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse
  ): zio.aws.mgn.model.DescribeVcenterClientsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mgn_2.13-5.17.267.6-sources.jar: zio/aws/mgn/model/DescribeVcenterClientsResponse.scala <==
package zio.aws.mgn.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.mgn.model.primitives.PaginationToken
import scala.jdk.CollectionConverters._
final case class DescribeVcenterClientsResponse(
    items: Optional[Iterable[zio.aws.mgn.model.VcenterClient]] =
      Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse = {
    import DescribeVcenterClientsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.DescribeVcenterClientsResponse.ReadOnly =
    zio.aws.mgn.model.DescribeVcenterClientsResponse.wrap(buildAwsValue())
}
object DescribeVcenterClientsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.DescribeVcenterClientsResponse =
      zio.aws.mgn.model.DescribeVcenterClientsResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Optional[List[zio.aws.mgn.model.VcenterClient.ReadOnly]]
    def nextToken: Optional[PaginationToken]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.mgn.model.VcenterClient.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse
  ) extends zio.aws.mgn.model.DescribeVcenterClientsResponse.ReadOnly {
    override val items
        : Optional[List[zio.aws.mgn.model.VcenterClient.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.mgn.model.VcenterClient.wrap(item)
          }.toList
        )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.mgn.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.DescribeVcenterClientsResponse
  ): zio.aws.mgn.model.DescribeVcenterClientsResponse.ReadOnly = new Wrapper(
    impl
  )
}
